@@ -645,6 +645,15 @@ class IterBetter:
             ...
         IndexError: already passed 3
 
+    It is also possible to get the first value of the iterator or None.
+
+        >>> c = iterbetter(iter([3, 4, 5]))
+        >>> print c.first()
+        3
+        >>> c = iterbetter(iter([]))
+        >>> print c.first()
+        None
+
     For boolean test, IterBetter peeps at first value in the itertor without effecting the iteration.
 
         >>> c = iterbetter(iter(range(5)))
@@ -661,6 +670,18 @@ class IterBetter:
     def __init__(self, iterator): 
         self.i, self.c = iterator, 0
 
+    def first(self, default=None):
+        """Returns the first element of the iterator or None when there are no
+        elements.
+
+        If the optional argument default is specified, that is returned instead
+        of None when there are no elements.
+        """
+        try:
+            return iter(self).next()
+        except StopIteration:
+            return default
+
     def __iter__(self): 
         if hasattr(self, "_head"):
             yield self._head
@@ -1493,7 +1514,7 @@ class _EmailMessage:
             c = boto.ses.SESConnection(
               aws_access_key_id=webapi.config.get('aws_access_key_id'),
               aws_secret_access_key=web.api.config.get('aws_secret_access_key'))
-            c.send_raw_email(self.from_address, message_text, self.from_recipients)
+            c.send_raw_email(self.from_address, message_text, self.recipients)
         else:
             sendmail = webapi.config.get('sendmail_path', '/usr/sbin/sendmail')
         
